@@ -12,11 +12,12 @@ extern "C" {
 /* public static native void Events(); */
 JNIEXPORT void JNICALL Java_javasci_Scilab_Events(JNIEnv *env , jobject obj_this);
   
-/* public static native int HaveAGraph(); */
-JNIEXPORT jint JNICALL Java_javasci_Scilab_HaveAGraph (JNIEnv *env , jobject obj_this);  
+/* public static native boolean HaveAGraph(); */
+JNIEXPORT jboolean JNICALL Java_javasci_Scilab_HaveAGraph (JNIEnv *env , jobject obj_this);
+
   
-/* public static native void Exec(String job); */
-JNIEXPORT void JNICALL Java_javasci_Scilab_Exec(JNIEnv *env , jclass cl, jstring job);
+/* public static native boolean Exec(String job); */
+JNIEXPORT jboolean JNICALL Java_javasci_Scilab_Exec(JNIEnv *env , jclass cl, jstring job);
 
 #ifdef __cplusplus
 }
