@@ -20,6 +20,13 @@
 #include "GetProperty.h"
 #include "bcg.h"
 
+
+#if WIN32
+#include "../os_specific/win_mem_alloc.h" /* MALLOC */
+#else
+#include "../os_specific/sci_mem_alloc.h" /* MALLOC */
+#endif
+
 sciHandleTab * PENDOFHANDLETAB;
 sciPointObj * PCURRENTPOBJ;
 
@@ -62,6 +69,7 @@ sciSetHandle (sciPointObj * pobj, sciHandleTab * pvalue)
       case SCI_AGREG:
       case SCI_MERGE:
       case SCI_LABEL: /* F.Leray 28.05.04 */
+      case SCI_UIMENU:
 	(sciGetRelationship (pobj))->phandle = pvalue;		/** put the new index handle */
 	break;
       default:
@@ -133,6 +141,7 @@ sciGetHandleTabPointer (sciPointObj * pobj)
     case SCI_AGREG:
     case SCI_MERGE: 
     case SCI_LABEL:
+    case SCI_UIMENU:
       return (sciHandleTab *) ((sciGetRelationship (pobj))->phandle);
     default:
       return (sciHandleTab *) NULL;
@@ -147,8 +156,8 @@ sciGetHandleTabPointer (sciPointObj * pobj)
 /**sciDelHandle
  * @memo Removes this pointed handle from the handle table
  */
-extern int
-sciDelHandle (sciPointObj * pobj)
+extern int sciDelHandle
+(sciPointObj * pobj)
 {
   int tmp = 0;
   sciHandleTab *phandletabtodel;	/* point to a handle structure (prev, value, next) */
@@ -202,8 +211,7 @@ sciDelHandle (sciPointObj * pobj)
 /**sciGetHandle
  * @memo Returns the handle 
  */
-long
-sciGetHandle (sciPointObj * pobj)
+long sciGetHandle (sciPointObj * pobj)
 {
   switch (sciGetEntityType (pobj))
     {
@@ -230,6 +238,7 @@ sciGetHandle (sciPointObj * pobj)
     case SCI_AGREG:
     case SCI_MERGE:  
     case SCI_LABEL: /* F.Leray 27.05.04 */
+    case SCI_UIMENU:
       return (sciGetRelationship (pobj))->phandle->index;
       break;
     default:
@@ -286,6 +295,7 @@ sciGetPointerFromHandle (long handle)
 sciRelationShip *
 sciGetRelationship (sciPointObj * pobj)
 {
+  sciRelationShip *tmp=NULL;
   switch (sciGetEntityType (pobj))
     {
     case SCI_FIGURE:
@@ -358,6 +368,10 @@ sciGetRelationship (sciPointObj * pobj)
     case SCI_LABEL: /* F.Leray 27.05.04 */
       return  &(pLABEL_FEATURE (pobj)->text.relationship);
       break;
+    case SCI_UIMENU: 
+      tmp=&(pUIMENU_FEATURE (pobj)->label.relationship);
+      return  &(pUIMENU_FEATURE (pobj)->label.relationship);
+      break;
     default:
       return (sciRelationShip *) NULL;
       break;
@@ -448,6 +462,9 @@ sciSetParent (sciPointObj * pson, sciPointObj * pparent)
     case SCI_LABEL: /* F.Leray 27.05.04 */
       (sciGetRelationship (pson))->pparent = pparent;
       break;
+    case SCI_UIMENU: 
+      (sciGetRelationship (pson))->pparent = pparent;
+      break;
     default:
       return -1;
       break;
@@ -462,79 +479,37 @@ sciSetParent (sciPointObj * pson, sciPointObj * pparent)
 sciPointObj *
 sciGetParent (sciPointObj * pobj)
 {
-  sciPointObj *tmp;
   switch (sciGetEntityType (pobj))
     {
-    case SCI_FIGURE:
-      return (sciPointObj *) (sciGetRelationship (pobj))->pparent;
-      break;
-    case SCI_SUBWIN:
-      return (sciPointObj *) (sciGetRelationship (pobj))->pparent;
-      break;
-    case SCI_TEXT:
-      return (sciPointObj *) (sciGetRelationship (pobj))->pparent;
-      break;
-    case SCI_TITLE:
-      return (sciPointObj *) (sciGetRelationship (pobj))->pparent;
-      break;
     case SCI_LEGEND:
-      tmp = (pLEGEND_FEATURE (pobj)->text.relationship).pparent;
-      return (sciPointObj *) tmp;
+      return (sciPointObj *) (pLEGEND_FEATURE (pobj)->text.relationship).pparent;
       break;
+    case SCI_FIGURE:
+    case SCI_SUBWIN:
+    case SCI_TEXT:
+    case SCI_TITLE:
     case SCI_ARC:
-      return (sciPointObj *) (sciGetRelationship (pobj))->pparent;
-      break;
     case SCI_SEGS:  
-      return (sciPointObj *) (sciGetRelationship (pobj))->pparent;
-      break; 
     case SCI_FEC: 
-      return (sciPointObj *) (sciGetRelationship (pobj))->pparent;
-      break; 
     case SCI_GRAYPLOT:
-      return (sciPointObj *) (sciGetRelationship (pobj))->pparent;
-      break; 
     case SCI_POLYLINE:
-      return (sciPointObj *) (sciGetRelationship (pobj))->pparent;
-      break;
     case SCI_RECTANGLE:
-      return (sciPointObj *) (sciGetRelationship (pobj))->pparent;
-      break;
     case SCI_SURFACE:
-      return (sciPointObj *) (sciGetRelationship (pobj))->pparent;
-      break;
     case SCI_LIGHT:
-      return (sciPointObj *)(sciGetRelationship (pobj))->pparent;
-      break;
     case SCI_AXES:
-      return (sciPointObj *) (sciGetRelationship (pobj))->pparent;
-      break;
     case SCI_PANNER:
-      return (sciPointObj *) (sciGetRelationship (pobj))->pparent;
-      break;
     case SCI_SBH:
-      return (sciPointObj *) (sciGetRelationship (pobj))->pparent;
-      break;
     case SCI_SBV:
-      return (sciPointObj *) (sciGetRelationship (pobj))->pparent;
-      break;
     case SCI_MENU:
-      return (sciPointObj *) (sciGetRelationship (pobj))->pparent;
-      break;
     case SCI_MENUCONTEXT:
-      return (sciPointObj *) (sciGetRelationship (pobj))->pparent;
-      break;
     case SCI_STATUSB:
-      return (sciPointObj *) (sciGetRelationship (pobj))->pparent;
-      break;
     case SCI_AGREG:
-      return (sciPointObj *) (sciGetRelationship (pobj))->pparent;
-      break;
     case SCI_MERGE:
-      return (sciPointObj *) (sciGetRelationship (pobj))->pparent;
-      break; 
     case SCI_LABEL: /* F.Leray 28.05.04 */
+    case SCI_UIMENU:
       return (sciPointObj *) (sciGetRelationship (pobj))->pparent;
       break; 
+	
     default:
       break;
     }
@@ -620,7 +595,10 @@ sciSetCurrentSon (sciPointObj * pparent, sciPointObj * pson)
       break;  
     case SCI_LABEL: /* F.Leray 28.05.04 */
       (sciGetRelationship (pparent))->pcurrentson = pson;
-      break;  
+      break; 
+    case SCI_UIMENU:
+      (sciGetRelationship (pparent))->pcurrentson = pson;
+      break; 
     default:
       break;
     }
@@ -704,6 +682,9 @@ sciGetCurrentSon (sciPointObj * pobj)
     case SCI_LABEL: /* F.Leray 28.05.04 : normally useless... */
       return (sciPointObj *) (sciGetRelationship (pobj))->pcurrentson;
       break;
+    case SCI_UIMENU:
+      return (sciPointObj *) (sciGetRelationship (pobj))->pcurrentson;
+      break;
     default:
       return (sciPointObj *) NULL;
       break;
@@ -751,6 +732,7 @@ sciAddThisToItsParent (sciPointObj * pthis, sciPointObj * pparent)
     case SCI_AGREG:
     case SCI_MERGE: 
     case SCI_LABEL: /* F.Leray 27.05.04 */
+    case SCI_UIMENU:
       /* Si c'est null alors il n'y a pas encore de fils d'affecte */
       if ((sciSons *) (sciGetRelationship (pparent)->psons) != NULL)
 	{			
@@ -802,7 +784,7 @@ sciDelThisToItsParent (sciPointObj * pthis, sciPointObj * pparent)
       /* on ne fait rien puisqu'il ne peut y avoir un parent dans ce cas */
       return TRUE;
     case SCI_POLYLINE:
- /*      printf("je vais detruire le lien entre polyline et subwin\n"); fflush(NULL); */
+      /*      printf("je vais detruire le lien entre polyline et subwin\n"); fflush(NULL); */
     case SCI_AGREG:
     case SCI_SUBWIN:
     case SCI_PANNER:
@@ -825,13 +807,14 @@ sciDelThisToItsParent (sciPointObj * pthis, sciPointObj * pparent)
     case SCI_ARC:
     case SCI_MERGE:
     case SCI_LABEL:
+    case SCI_UIMENU:
       /* recherche de l'objet a effacer*/
       OneSon = (sciGetRelationship (pparent)->psons);
       OneSonprev = OneSon;
       tmp = 0;
       while ( (OneSon != NULL) &&  (OneSon->pointobj != pthis) )
 	{
-	  OneSonprev = OneSon;/* on garde une trace du precedant */
+	  OneSonprev = OneSon;/* on garde une trace du precedent*/
 	  OneSon = (sciSons *) OneSon->pnext;
 	}/* fin du while */
       /* dans quel cas de figure somme nous ? */
@@ -969,6 +952,10 @@ sciGetSons (sciPointObj * pobj)
       
       return (sciSons *) (sciGetRelationship (pobj)->psons);
       break;
+    case SCI_UIMENU:
+      return (sciSons *) (sciGetRelationship (pobj)->psons);
+      break;
+
     default:
       return (sciSons *) NULL;
       break;
@@ -1055,6 +1042,9 @@ sciGetLastSons (sciPointObj * pobj)
     case SCI_LABEL: /* F.Leray 28.05.04 : normally useless... */
       return (sciSons *)sciGetRelationship (pobj)->plastsons;
       break;
+    case SCI_UIMENU:
+      return (sciSons *)sciGetRelationship (pobj)->plastsons;
+      break;
     default:
       return (sciSons *) NULL;
       break;
@@ -1105,9 +1095,9 @@ sciSetCurrentObj (sciPointObj * pobj)
   
   PCURRENTPOBJ = pobj;
   /*
-  sciprint (" IN sciSetCurrentObj, AFTER setting, *PCURRENTPOBJ = %d\r\n",&(*PCURRENTPOBJ));
-  sciprint (" IN sciSetCurrentObj, AFTER setting, *PCURRENTPOBJ->EntityType = %s\r\n",sciGetCharEntityType(PCURRENTPOBJ));
-  sciprint ("------------------------------------------------------------------------\n");*/
+    sciprint (" IN sciSetCurrentObj, AFTER setting, *PCURRENTPOBJ = %d\r\n",&(*PCURRENTPOBJ));
+    sciprint (" IN sciSetCurrentObj, AFTER setting, *PCURRENTPOBJ->EntityType = %s\r\n",sciGetCharEntityType(PCURRENTPOBJ));
+    sciprint ("------------------------------------------------------------------------\n");*/
   return 0;
 }
 
