@@ -1,3 +1,6 @@
+#ifndef __DEF_H__
+#define __DEF_H__
+
 typedef long int /* long int */ integer;
 typedef unsigned long int /* long */ uinteger;
 typedef char *address;
@@ -10,3 +13,6 @@ typedef long int /* long int */ logical;
 typedef short int shortlogical;
 typedef char logical1;
 typedef char integer1;
+
+#endif /*__DEF_H__*/
+
