@@ -25,8 +25,8 @@ c
 c     functions/fin
 c     1       2       3       4       5           6       7       8   
 c     length    part   string  convstr  emptystr str2code code2str sort
-c     9         10       11        12    13    14
-c     strcat    strindex strsubst ascii  grep tokens
+c     9         10       11        12    13    14     15
+c     strcat    strindex strsubst ascii  grep tokens  strsplit
 
 c     
 c      if ( fin.eq.8)  then 
@@ -36,7 +36,7 @@ c         call cstrelm()
 c      endif
 c      return 
 
-      goto (10,20,25,50,60,70,80,90,100,110,120,125,130, 135) fin
+      goto (10,20,25,50,60,70,80,90,100,110,120,125,130, 135,140) fin
 c     
 c     length
 c     
@@ -113,6 +113,11 @@ c     tokens(str [,sep])
       call inttokens(id)
       goto 900
 
+c     strsplit(str,v)
+ 140  continue
+      call intstrsplit(id)
+      goto 900
+
 c     
  900  return
       end
@@ -198,7 +203,7 @@ c
          if(istk(il2).ne.10) then 
             fun=-1
             top=tops
-            call funnam(ids(1,pt+1),'strcat',iadr(lstk(top)))
+            call funnam(ids(1,pt+1),'strcat',il2)
             return
          endif
          if(istk(il2+1)*istk(il2+2).ne.1) then
@@ -231,7 +236,7 @@ c
       if(istk(il1).ne.10) then
          fun=-1
          top=tops
-         call funnam(ids(1,pt+1),'strcat',iadr(lstk(top+1-rhs)))
+         call funnam(ids(1,pt+1),'strcat',il1)
          return
       endif
 
@@ -311,7 +316,7 @@ c
       if(istk(il2).ne.10) then 
          fun=-1
          top=tops
-         call funnam(ids(1,pt+1),'strindex',iadr(lstk(top)))
+         call funnam(ids(1,pt+1),'strindex',il2)
          return
       endif
       mn2=istk(il2+1)*istk(il2+2)
@@ -350,7 +355,7 @@ c
       if(istk(il1).ne.10) then
          fun=-1
          top=tops
-         call funnam(ids(1,pt+1),'strindex',iadr(lstk(top+1-rhs)))
+         call funnam(ids(1,pt+1),'strindex',il1)
          return
       endif
       if(istk(il1+1)*istk(il1+2).ne.1) then
@@ -511,7 +516,7 @@ c
       if(istk(il3).ne.10) then 
          fun=-1
          top=tops
-         call funnam(ids(1,pt+1),'strsubst',iadr(lstk(top)))
+         call funnam(ids(1,pt+1),'strsubst',il3)
          return
       endif
       if(istk(il3+1)*istk(il3+2).ne.1) then
@@ -528,7 +533,7 @@ c
       if(istk(il2).ne.10) then 
          fun=-1
          top=tops
-         call funnam(ids(1,pt+1),'strsubst',iadr(lstk(top-1)))
+         call funnam(ids(1,pt+1),'strsubst',il2)
          return
       endif
       if(istk(il2+1)*istk(il2+2).ne.1) then
@@ -563,7 +568,7 @@ c
       if(istk(il1).ne.10) then
          fun=-1
          top=tops
-         call funnam(ids(1,pt+1),'strsubst',iadr(lstk(top-2)))
+         call funnam(ids(1,pt+1),'strsubst',il1)
          return
       endif
 
@@ -711,7 +716,7 @@ c
          lstk(top+1)=l+mn1
       else
          fun=-1
-         call funnam(ids(1,pt+1),'length',iadr(lstk(top)))
+         call funnam(ids(1,pt+1),'length',il1)
          return
       endif
       return
@@ -741,7 +746,7 @@ c
 
       if(istk(il1).ne.10) then
          fun=-1
-         call funnam(ids(1,pt+1),'part',iadr(lstk(top+1-rhs)))
+         call funnam(ids(1,pt+1),'part',il1)
          return
       endif
 c
@@ -1047,7 +1052,7 @@ c
         goto 999
       else
          fun=-1
-         call funnam(ids(1,pt+1),'string',iadr(lstk(top+1-rhs)))
+         call funnam(ids(1,pt+1),'string',il)
          return
       endif
  999  return
@@ -1102,10 +1107,12 @@ c     conversion flag
 c
    51 continue
       il1=iadr(lstk(top))
-      if(abs(istk(il1)).ne.10) then
-         if(abs(istk(il1)).eq.1) then
-            if(istk(il1).lt.0) il1=iadr(istk(il1+1))
-            if(istk(il1+1)*istk(il1+2).eq.0) then
+      
+      il=il1
+      if(istk(il).lt.0) il=iadr(istk(il+1))
+      if(istk(il).ne.10) then
+         if(istk(il1).eq.1) then
+            if(istk(il+1)*istk(il+2).eq.0) then
 c              convstr([])
                lgq=cremat('convstr', top, 0, 0, 0, lr, lc)
                return
@@ -1113,7 +1120,7 @@ c              convstr([])
          endif
          top=tops
          fun=-1
-         call funnam(ids(1,pt+1),'convstr',iadr(lstk(top+1-rhs)))
+         call funnam(ids(1,pt+1),'convstr',il)
          return
       endif
 
@@ -1211,13 +1218,14 @@ c
          m=int(stk(sadr(il+4)))
       elseif(rhs.eq.1) then
          il=iadr(lstk(top))
-         if(abs(istk(il)).gt.10) then
+         ilr=il
+         if(istk(il).lt.0) il=iadr(istk(il+1))
+
+         if(istk(il).gt.10) then
             fun=-1
             call funnam(ids(1,pt+1),'emptystr',il)
             return
          endif
-         ilr=il
-         if(istk(il).lt.0) il=iadr(istk(il+1))
          ref=ilr.ne.il
          m=istk(il+1)
          n=istk(il+2)
@@ -1273,7 +1281,7 @@ c
       ref=ilr.ne.il1
       if (istk(il1) .ne. 10) then
          fun=-1
-         call funnam(ids(1,pt+1),'str2code',ilr)
+         call funnam(ids(1,pt+1),'str2code',il1)
          return
       endif
 
@@ -1326,7 +1334,7 @@ c
       if(istk(il1).lt.0) il1=iadr(istk(il1+1))
       if (istk(il1) .ne. 1) then
          fun=-1
-         call funnam(ids(1,pt+1),'code2str2',ilr)
+         call funnam(ids(1,pt+1),'code2str2',il1)
          return
       endif
       ref=ilr.ne.il1
@@ -1572,7 +1580,7 @@ c     argument is a scilab string return a vector of ascii codes
          lstk(top+1)=lr+n
       else
          fun=-1
-         call funnam(ids(1,pt+1),'ascii',iadr(lstk(top)))
+         call funnam(ids(1,pt+1),'ascii',il)
       endif
       end
 
@@ -1605,7 +1613,7 @@ c
       if(istk(il2).ne.10) then 
          fun=-1
          top=tops
-         call funnam(ids(1,pt+1),'grep',iadr(lstk(top)))
+         call funnam(ids(1,pt+1),'grep',il2)
          return
       endif
       mn2=istk(il2+1)*istk(il2+2)
@@ -1636,7 +1644,7 @@ c
       if(istk(il1).ne.10) then
          fun=-1
          top=tops
-         call funnam(ids(1,pt+1),'grep',iadr(lstk(top+1-rhs)))
+         call funnam(ids(1,pt+1),'grep',il1)
          return
       endif
 c
@@ -1814,7 +1822,7 @@ c        get the separators sep
          if (istk(il2).ne.10) then 
             fun=-1
             top=tops
-            call funnam(ids(1,pt+1),'tokens',iadr(lstk(top)))
+            call funnam(ids(1,pt+1),'tokens',il2)
             return
          endif
          m2 = istk(il2+1)
@@ -1852,7 +1860,7 @@ c     get the string str
       if(istk(il1).ne.10) then 
          fun = -1
          top = tops
-         call funnam(ids(1,pt+1),'tokens',iadr(lstk(top-1)))
+         call funnam(ids(1,pt+1),'tokens',il1)
          return
       endif
       if(istk(il1+1)*istk(il1+2).ne.1) then 
@@ -1963,3 +1971,119 @@ c
       enddo
 
       end 
+      subroutine intstrsplit(id)
+      INCLUDE '../stack.h'
+c
+      integer id(nsiz),vol,tops
+      logical ref1,ref2
+c
+      integer iadr,sadr
+c
+      iadr(l)=l+l-1
+      sadr(l)=(l/2)+1
+c
+c     strsplit(str,v)
+c
+
+      if(rhs.ne.2) then
+         call error(39)
+         return
+      endif
+      if (lhs .ne. 1) then
+         call error(41)
+         return
+      endif
+c     
+      tops=top
+c
+      lw=lstk(top+1)
+
+      il2=iadr(lstk(top))
+      ref2=istk(il2).lt.0
+      if(ref2) il2=iadr(istk(il2+1))
+
+      if(istk(il2).ne.1) then 
+         fun=-1
+         top=tops
+         call funnam(ids(1,pt+1),'strsplit',il2)
+         return
+      endif
+      n2=istk(il2+1)*istk(il2+2)
+      l2=sadr(il2+4)
+      if (stk(l2).lt.1) then
+         err=2
+         call error(116)
+         return
+      endif
+      do i=1,n2-1
+         if (stk(l2+i).lt.stk(l2+i-1)) then
+            err=2
+            call error(99)
+            return
+         endif
+      enddo
+c
+      top=top-1
+      il1=iadr(lstk(top))
+      ref1=istk(il1).lt.0
+      if(ref1) il1=iadr(istk(il1+1))
+
+      if(istk(il1).eq.1) then
+         if(istk(il1+1)*istk(il1+2).eq.0) then
+            ilr=iadr(lstk(top))
+            istk(ilr)=1
+            istk(ilr+1)=0
+            istk(ilr+2)=0
+            istk(ilr+3)=0
+            lstk(top+1)=sadr(ilr+4)
+            return
+         endif
+      endif
+      if(istk(il1).ne.10) then
+         fun=-1
+         top=tops
+         call funnam(ids(1,pt+1),'strsplit',il1)
+         return
+      endif
+      if (istk(il1+1)*istk(il1+2).ne.1) then
+         err=1
+         call error(89)
+         return
+      endif
+      id1=il1+4
+      l1=id1+2
+      vol=istk(id1+1)-1
+      if (stk(l2+n2-1).ge.vol) then
+         err=2
+         call error(116)
+         return
+      endif
+      if(ref1.and.ref2) then
+         ilr=iadr(lstk(top))
+      else
+         ilr=iadr(lw)
+         err = sadr(ilr+4+n2+2+vol) - lstk(bot)
+         if ( err.gt.0 ) then
+            call error(17)
+            return
+         endif
+      endif
+      istk(ilr)=10
+      istk(ilr+1)=n2+1
+      istk(ilr+2)=1
+      istk(ilr+3)=0
+
+      istk(ilr+4)=1
+      do i=1,n2
+         istk(ilr+4+i)=stk(l2+i-1)+1
+      enddo
+      istk(ilr+5+n2)=vol+1
+      call icopy(vol,istk(l1),1,istk(ilr+6+n2),1)
+      if(ref1.and.ref2) then
+         lstk(top+1)=sadr(ilr+6+n2+vol)
+      else
+         il=iadr(lstk(top))
+         call icopy(6+n2+vol,istk(ilr),1,istk(il),1)
+         lstk(top+1)=sadr(il+6+n2+vol)
+      endif
+      end
