@@ -11,6 +11,12 @@
 #include "men_scilab.h"
 #endif
 
+#ifdef WIN32
+#include "../os_specific/win_mem_alloc.h" /* MALLOC */
+#else
+#include "../os_specific/sci_mem_alloc.h" /* MALLOC */
+#endif
+
 SciStuff **Everything = NULL;
 
 /*************************************************
