@@ -5,8 +5,13 @@
 #include "men_scilab.h"
 #endif
 
-#include "../sun/Sun.h"
+#include "../os_specific/Os_specific.h"
 
+#ifdef WIN32
+#include "../os_specific/win_mem_alloc.h" /* MALLOC */
+#else
+#include "../os_specific/sci_mem_alloc.h" /* MALLOC */
+#endif
 
 /****************************************************
  * Scilab xgetfile command used to get a file name 
