@@ -20,7 +20,7 @@ c!origine
 c     Serge Steer INRIA
 c!
 c     Copyright INRIA
-      double precision a,a1,ent,dec,round,dlamch
+      double precision a,a1,ent,dec,sciround,dlamch
       integer typ,n1,n2,maxc
       logical v
 c
@@ -54,7 +54,7 @@ c     testing Inf
       n2=0
       a1=dec*10.0d+0**(ndgt+1)
 c      dec=(a1-mod(a1,10.0d+0))/10.0d+0
-      dec=round(a1/10.0d+0)
+      dec=sciround(a1/10.0d+0)
       if(dec.eq.0.0d+0) return
       n2=ndgt
    11 if(mod(dec,10.0d+0).ne.0.0d+0) goto 12
@@ -70,7 +70,7 @@ c
       ndgt=maxc-3+m
 
       if(m.gt.maxc-3) goto 25
-      dec=round(a*10.0d+0**ndgt)
+      dec=sciround(a*10.0d+0**ndgt)
    21 if(mod(dec,10.0d+0).ne.0.0d+0) goto 22
       dec=dec/10.0d+0
       ndgt=ndgt-1
