@@ -10,12 +10,7 @@ cc
       integer nipar,nu,ny
 c
       double precision ww
-      common /dbcos/ idb
-c
-      if(idb.eq.1) then
-         write(6,'(''Minblk   t='',e10.3,'' flag='',i1)') t,flag
-      endif
-      
+c      
       ww=u(1)
       do 15 i=1,nu
          ww=min(ww,u(i))
