@@ -1,7 +1,7 @@
 # ----------------------------------------------------------------------------
 #  listbox.tcl
 #  This file is part of Unifix BWidget Toolkit
-#  $Id: listbox.tcl,v 1.1 2004/07/15 13:23:28 leray Exp $
+#  $Id: listbox.tcl,v 1.2 2005/12/07 10:38:15 pmarecha Exp $
 # ----------------------------------------------------------------------------
 #  Index of commands:
 #     - ListBox::create
@@ -101,6 +101,7 @@ namespace eval ListBox {
 
     Widget::addmap ListBox "" .c {-deltay -yscrollincrement}
 
+    bind ListBox <FocusIn>   [list after idle {BWidget::refocus %W %W.c}]
     bind ListBox <Destroy>   [list ListBox::_destroy %W]
     bind ListBox <Configure> [list ListBox::_resize  %W]
     bind ListBoxFocus <1>    [list focus %W]
@@ -120,7 +121,8 @@ proc ListBox::create { path args } {
     variable $path
     upvar 0  $path data
 
-    frame $path -class ListBox -bd 0 -highlightthickness 0 -relief flat
+    frame $path -class ListBox -bd 0 -highlightthickness 0 -relief flat \
+	-takefocus 0
     # For 8.4+ we don't want to inherit the padding
     catch {$path configure -padx 0 -pady 0}
     # widget informations
@@ -142,7 +144,7 @@ proc ListBox::create { path args } {
     set data(dnd,item)     ""
 
     eval [list canvas $path.c] [Widget::subcget $path .c] \
-	 [list -xscrollincrement 8 -highlightthickness 1]
+	[list -xscrollincrement 8]
     pack $path.c -expand yes -fill both
 
     DragSite::setdrag $path $path.c ListBox::_init_drag_cmd \
@@ -156,13 +158,23 @@ proc ListBox::create { path args } {
     set dy [Widget::cget $path -deltay]
     $path.c configure -width [expr {$w*8}] -height [expr {$h*$dy}]
 
-    ## Let any click within the canvas focus on the canvas so that
-    ## MouseWheel scroll events will be properly handled by the
-    ## canvas.
+    # Insert $path into the canvas bindings, so that anyone binding
+    # directly onto the widget will see their bindings activated when
+    # the canvas has focus.
+    set bindtags [bindtags $path.c]
+    set bindtags [linsert $bindtags 1 $path]
+    # Let any click within the canvas focus on the canvas so that
+    # MouseWheel scroll events will be properly handled by the canvas.
     if {[Widget::cget $path -autofocus]} {
-	bindtags $path.c [concat [bindtags $path.c] ListBoxFocus]
+	lappend bindtags ListBoxFocus
 	BWidget::bindMouseWheel $path.c
     }
+    bindtags $path.c $bindtags
+
+    # Add slightly modified up/down bindings to the canvas, in case
+    # it gets the focus (like with -autofocus).
+    bind $path.c <Key-Up> {ListBox::_keyboard_navigation [winfo parent %W] -1}
+    bind $path.c <Key-Down> {ListBox::_keyboard_navigation [winfo parent %W] 1}
 
     switch -exact -- [Widget::getoption $path -selectmode] {
 	single {
@@ -416,10 +428,9 @@ proc ListBox::bindText { path event script } {
     if { $script != "" } {
         set map [list %W $path]
         set script [string map $map $script]
-        $path.c bind "click" $event "$script \[ListBox::_get_current $path]"
-    } else {
-        $path.c bind "click" $event {}
+	append script " \[ListBox::_get_current [list $path]\]"
     }
+    $path.c bind "click" $event $script
 }
 
 
@@ -430,10 +441,9 @@ proc ListBox::bindImage { path event script } {
     if { $script != "" } {
         set map [list %W $path]
         set script [string map $map $script]
-        $path.c bind "img" $event "$script \[ListBox::_get_current $path]"
-    } else {
-        $path.c bind "img" $event {}
+	append script " \[ListBox::_get_current [list $path]\]"
     }
+    $path.c bind "img" $event $script
 }
 
 
@@ -751,7 +761,7 @@ proc ListBox::edit { path item text {verifycmd ""} {clickres 0} {select 1}} {
         set ok 0
         while { !$ok } {
             tkwait variable ListBox::_edit(wait)
-            if { !$_edit(wait) || $verifycmd == "" ||
+            if { !$_edit(wait) || [llength $verifycmd]==0 ||
                  [uplevel \#0 $verifycmd [list $_edit(text)]] } {
                 set ok 1
             }
@@ -776,7 +786,7 @@ proc ListBox::edit { path item text {verifycmd ""} {clickres 0} {select 1}} {
 #  Command ListBox::xview
 # ----------------------------------------------------------------------------
 proc ListBox::xview { path args } {
-    return [eval [list $path.c xview] $args]
+    return [eval [linsert $args 0 $path.c xview]]
 }
 
 
@@ -784,7 +794,7 @@ proc ListBox::xview { path args } {
 #  Command ListBox::yview
 # ----------------------------------------------------------------------------
 proc ListBox::yview { path args } {
-    return [eval [list $path.c yview] $args]
+    return [eval [linsert $args 0 $path.c yview]]
 }
 
 
@@ -938,10 +948,8 @@ proc ListBox::_update_select_fill { path } {
 # ----------------------------------------------------------------------------
 #  Command ListBox::_draw_item
 # ----------------------------------------------------------------------------
-proc ListBox::_draw_item { path item x0 x1 y } {
+proc ListBox::_draw_item {path item x0 x1 y bg selfill multi ww} {
     set indent  [Widget::getoption $path.$item -indent]
-    set selfill [Widget::cget $path -selectfill]
-    set multi   [Widget::cget $path -multicolumn]
     set i [$path.c create text [expr {$x1+$indent}] $y \
         -text   [Widget::getoption $path.$item -text] \
         -fill   [_getoption        $path $item -foreground] \
@@ -950,10 +958,8 @@ proc ListBox::_draw_item { path item x0 x1 y } {
         -tags   [list item n:$item click]]
 
     if { $selfill && !$multi } {
-        set bg    [Widget::cget $path -background]
-        set width [winfo width $path.c]
         set bbox  [$path.c bbox n:$item]
-        set bbox  [list 0 [lindex $bbox 1] $width [lindex $bbox 3]]
+        set bbox  [list 0 [lindex $bbox 1] $ww [lindex $bbox 3]]
         set tags  [list box b:$item click]
         $path.c create rect $bbox -fill $bg -width 0 -tags $tags
         $path.c raise $i
@@ -980,6 +986,7 @@ proc ListBox::_redraw_items { path } {
 
     set cursor [$path.c cget -cursor]
     $path.c configure -cursor watch
+    update idletasks ; # make sure watch cursor is reflected
     set dx   [Widget::getoption $path -deltax]
     set dy   [Widget::getoption $path -deltay]
     set padx [Widget::getoption $path -padx]
@@ -997,9 +1004,15 @@ proc ListBox::_redraw_items { path } {
     foreach item $data(upd,delete) {
         $path.c delete i:$item n:$item s:$item b:$item
     }
+    # Pass these to _draw_item so it doesn't have to request them
+    # for each item.
+    set bg      [Widget::cget $path -background]
+    set selfill [Widget::cget $path -selectfill]
+    set multi   [Widget::cget $path -multicolumn]
+    set ww      [winfo width $path]
     foreach item $data(items) {
         if { [info exists data(upd,create,$item)] } {
-            _draw_item $path $item $x0 $x1 $y0
+            _draw_item $path $item $x0 $x1 $y0 $bg $selfill $multi $ww
             unset data(upd,create,$item)
         } else {
             set indent [Widget::getoption $path.$item -indent]
@@ -1011,7 +1024,7 @@ proc ListBox::_redraw_items { path } {
         lappend drawn n:$item
         if { $nitem == $nrows } {
             set y0    [expr {$dy/2}]
-            set bbox  [eval [list $path.c bbox] $drawn]
+            set bbox  [eval [linsert $drawn 0 $path.c bbox]]
             set drawn {}
             set x0    [expr {[lindex $bbox 2]+$dx}]
             set x1    [expr {$x0+$padx}]
@@ -1020,7 +1033,7 @@ proc ListBox::_redraw_items { path } {
         }
     }
     if { $nitem && $nitem < $nrows } {
-        set bbox  [eval [list $path.c bbox] $drawn]
+        set bbox  [eval [linsert $drawn 0 $path.c bbox]]
         lappend data(xlist) [lindex $bbox 2]
     }
     set data(upd,delete) {}
@@ -1045,15 +1058,17 @@ proc ListBox::_redraw_selection { path } {
             -fill [_getoption $path $item -foreground]
     }
     $path.c delete sel
+    if {$selfill && !$multi} {
+	# cache window width for use below
+	set width [winfo width $path]
+    }
     foreach item $data(selitems) {
         set bbox [$path.c bbox "n:$item"]
-        if { $selfill && !$multi } {
-            set bbox2 [$path.c bbox "b:$item"]
-            set w1 [lindex $bbox 2]
-            set w2 [lindex $bbox2 2]
-            if {$w1 < $w2} { set bbox $bbox2 }
-        }
         if { [llength $bbox] } {
+	    if { $selfill && !$multi } {
+		# With -selectfill, make box occupy full width of widget
+		set bbox [list 0 [lindex $bbox 1] $width [lindex $bbox 3]]
+	    }
             set tags [list sel s:$item click]
             set id [$path.c create rectangle $bbox \
                 -fill $selbg -outline $selbg -tags $tags]
@@ -1078,6 +1093,9 @@ proc ListBox::_redraw_listbox { path } {
         }
         _redraw_selection $path
         _update_scrollregion $path
+        if {[Widget::cget $path -selectfill]} {
+            _update_select_fill $path
+        }
         set data(upd,level)   0
         set data(upd,afterid) ""
     }
@@ -1094,7 +1112,8 @@ proc ListBox::_redraw_idle { path level } {
     if { $data(nrows) != -1 } {
         # widget is realized
         if { [Widget::getoption $path -redraw] && $data(upd,afterid) == "" } {
-            set data(upd,afterid) [after idle ListBox::_redraw_listbox $path]
+            set data(upd,afterid) \
+		[after idle [list ListBox::_redraw_listbox $path]]
         }
     }
     if { $level > $data(upd,level) } {
@@ -1152,7 +1171,7 @@ proc ListBox::_init_drag_cmd { path X Y top } {
          [string equal $item "img"]  ||
          [string equal $item "win"] } {
         set item [string range [lindex $ltags 1] 2 end]
-        if { [set cmd [Widget::getoption $path -draginitcmd]] != "" } {
+        if {[llength [set cmd [Widget::getoption $path -draginitcmd]]]} {
             return [uplevel \#0 $cmd [list $path $item $top]]
         }
         if { [set type [Widget::getoption $path -dragtype]] == "" } {
@@ -1182,7 +1201,7 @@ proc ListBox::_drop_cmd { path source X Y op type dnddata } {
     $path.c delete drop
     set data(dnd,scroll) ""
     if { [llength $data(dnd,item)] || ![llength $data(items)] } {
-        if { [set cmd [Widget::getoption $path -dropcmd]] != "" } {
+        if {[llength [set cmd [Widget::getoption $path -dropcmd]]]} {
             return [uplevel \#0 $cmd [list $path $source $data(dnd,item) $op $type $dnddata]]
         }
     }
@@ -1311,7 +1330,7 @@ proc ListBox::_over_cmd { path source event X Y op type dnddata } {
         }
     }
 
-    if { $vmode && [set cmd [Widget::getoption $path -dropovercmd]] != "" } {
+    if {$vmode && [llength [set cmd [Widget::getoption $path -dropovercmd]]]} {
         # user-defined dropover command
         set res   [uplevel \#0 $cmd [list $source $target $op $type $dnddata]]
         set code  [lindex $res 0]
@@ -1406,7 +1425,7 @@ proc ListBox::_auto_scroll { path x y } {
 
     set data(dnd,scroll) $scroll
     if { [llength $scroll] && ![string length $data(dnd,afterid)] } {
-        set data(dnd,afterid) [after 200 ListBox::_scroll $path $scroll]
+        set data(dnd,afterid) [after 200 [list ListBox::_scroll $path $scroll]]
     }
     return $data(dnd,afterid)
 
@@ -1479,7 +1498,8 @@ proc ListBox::_scroll { path cmd dir } {
     if { ($dir == -1 && [lindex [$path.c $cmd] 0] > 0) ||
          ($dir == 1  && [lindex [$path.c $cmd] 1] < 1) } {
         $path $cmd scroll $dir units
-        set data(dnd,afterid) [after 100 ListBox::_scroll $path $cmd $dir]
+        set data(dnd,afterid) \
+	    [after 100 [list ListBox::_scroll $path $cmd $dir]]
     } else {
         set data(dnd,afterid) ""
         DropSite::setcursor dot
@@ -1502,7 +1522,7 @@ proc ListBox::_set_help { path node } {
 
     set item $path.$node
     set opts [list -helptype -helptext -helpvar]
-    foreach {cty ctx cv} [eval [list Widget::hasChangedX $item] $opts] break
+    foreach {cty ctx cv} [eval [linsert $opts 0 Widget::hasChangedX $item]] break
     set text [Widget::getoption $item -helptext]
 
     ## If we've never set help for this item before, and text is not blank,
@@ -1539,7 +1559,7 @@ proc ListBox::_set_help { path node } {
 # Results:
 #	none
 proc ListBox::_mouse_select { path cmd args } {
-    eval selection [list $path] [list $cmd] $args
+    eval [linsert $args 0 selection $path $cmd]
     switch -- $cmd {
         "add" - "clear" - "remove" - "set" {
             event generate $path <<ListboxSelect>>
@@ -1591,7 +1611,7 @@ proc ListBox::_drag_and_drop { path from endItem operation type startItem } {
 
     if {[string equal $operation "copy"]} {
         set options [Widget::options $path.$startItem]
-        eval $path insert $idx [list $startItem#auto] $options
+        eval [linsert $options 0 $path insert $idx $startItem\#auto]
     } else {
         $path move $startItem $idx
     }
@@ -1610,5 +1630,7 @@ proc ListBox::_keyboard_navigation { path dir } {
 	incr sel -1
 	if {$sel < 0} { return }
     }
-    _mouse_select $path set [lindex $data(items) $sel]
+    set item [lindex $data(items) $sel]
+    $path see $item
+    _mouse_select $path set $item
 }
